# Copyright (C) 2009, 2010 by Intevation GmbH
# Authors:
# Bernhard Herzog <bh@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file COPYING coming with the software for details.

"""Tests for inteproxy.httpserver and serversupport

The tests of inteproxy.httpserver are done indirectly via the server
implemented in serversupport so that the tests server more or less as
tests for both modules.
"""

import sys
import os
import httplib
import unittest
import subprocess

import support


class TestCreateRewriteRules(unittest.TestCase, support.FileTestMixin):

    def setUp(self):
        self.create_rewrite_rules_program = \
                         os.path.join(os.path.dirname(__file__), os.pardir,
                                      "create-rewrite-rules.py")

    def run_test(self, config_contents, expected_rules):
        config_filename = self.create_temp_file("config", config_contents)
        rules_filename = self.create_temp_file("rules", "")
        error_filename = self.create_temp_file("errors", "")
        error_file = open(error_filename, "w")
        try:
            command = [self.create_rewrite_rules_program,
                       "--config-file=" + config_filename,
                       "--server-prefix=http://localhost:64609/",
                       "-o", rules_filename]
            process = subprocess.Popen(command, stderr=error_file)
            ret = process.wait()
            if ret != 0:
                raise RuntimeError("%r failed with exit code %d"
                                   % (command, ret))

        finally:
            error_file.close()

        self.check_file_contents(rules_filename, expected_rules)


    def test_create_rewrite_rules_no_wild_cards(self):
        self.run_test("""[inteproxy-rules]
urls=owsproxy://bob:secret@demo.intevation.de/wms
""",
                      """\
RewriteRule ^/demo\\.intevation\\.de\\/wms$ https:/$0?user=bob&password=secret [QSA,P]
Substitute s!https?://(demo\\.intevation\\.de\\/wms)!http://localhost:64609/$1!
""")

    def test_create_rewrite_rules_wild_cards(self):
        self.run_test("""[inteproxy-rules]
urls=owsproxy://bob:secret@*.intevation.de/wms/*
""",
                      """\
RewriteRule ^/[^/]*\\.intevation\\.de\\/wms\\/.*$ https:/$0?user=bob&password=secret [QSA,P]
Substitute s!https?://([^/]*\\.intevation\\.de\\/wms\\/.*)!http://localhost:64609/$1!
""")

    def test_create_rewrite_rules_wild_cards_special_characters(self):
        self.run_test("""[inteproxy-rules]
urls=owsproxy://bob:$ec%%20ret!@*.intevation.de/wms/*
""",
                      """\
RewriteRule ^/[^/]*\\.intevation\\.de\\/wms\\/.*$ https:/$0?user=bob&password=\\%24ec\\+ret\\%21 [QSA,P]
Substitute s!https?://([^/]*\\.intevation\\.de\\/wms\\/.*)!http://localhost:64609/$1!
""")

    def test_create_rewrite_rules_port(self):
        self.run_test("""[inteproxy-rules]
urls=owsproxy://bob:secret@*.intevation.de:8000/wms/*
""",
                      """\
RewriteRule ^/[^/]*\\.intevation\\.de\\:8000\\/wms\\/.*$ https:/$0?user=bob&password=secret [QSA,P]
Substitute s!https?://([^/]*\\.intevation\\.de\\:8000\\/wms\\/.*)!http://localhost:64609/$1!
""")
