# Copyright (C) 2012 by Intevation GmbH
# Authors:
# Andre Heinecke <aheinecke@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file COPYING coming with the software for details

"""Tests for the inteproxy.decompressstream module"""

import unittest
import StringIO
import zlib

from random import Random

from inteproxy.decompressstream import DecompressStream

class DecompressStreamTest(unittest.TestCase):

    def test_read_amounts(self):
        """Test for the ChunkedTransferEncodingWriter"""

        DATA = "It's still magic even if you know how it's done."

        compressed_data = zlib.compress(DATA)
        compressed_stream = StringIO.StringIO(compressed_data)
        decompressobj = zlib.decompressobj()

        dstream = DecompressStream(compressed_stream, decompressobj)

        # Test reading small "bites"
        result = dstream.read(5)
        self.assertEqual(result, DATA[:5])
        result2 = dstream.read(1)
        self.assertEqual(result2, DATA[5])
        result3 = dstream.read(-123)
        self.assertEqual(result + result2 + result3, DATA)

        # Test reading everything
        compressed_stream = StringIO.StringIO(compressed_data)
        decompressobj = zlib.decompressobj()

        dstream = DecompressStream(compressed_stream, decompressobj)
        self.assertEqual(dstream.read(), DATA)
